@@ -2,11 +2,19 @@ import subprocess
 import os
 import platform
 
+def desk():
+    if platform.system() == "Darwin":
+        return os.path.expanduser("~/Desktop/")
+    elif platform.system() == "Windows":
+        import winreg
+        key = winreg.OpenKey(winreg.HKEY_CURRENT_USER, r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders')
+        return winreg.QueryValueEx(key, "Desktop")[0] + "/"
+    else:
+        return os.path.expanduser("~/Desktop/")
 
 def xopen(file_name=None):
     if file_name:
-        pre_path = os.path.expanduser("~/Desktop/")
-        new_path = pre_path + file_name
+        new_path = desk() + file_name
         if not os.path.exists(new_path):
             os.mkdir(new_path)
     else:
